# Copyright 2016 Canonical Limited.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from unittest import TestCase

from charmhelpers.contrib.hardening.host.checks import login


class LoginTestCase(TestCase):

    def test_login(self):
        audits = login.get_audits()
        self.assertEqual(1, len(audits))
        audit = audits[0]
        self.assertTrue(isinstance(audit, login.TemplatedFile))
        self.assertEqual('/etc/login.defs', audit.paths[0])
